@@ -1,5 +1,6 @@
 from .iai import _IAI, _requires_iai_version
-from .iaibase import (Learner, ClassificationLearner, RegressionLearner)
+from .iaibase import (Learner, ClassificationLearner, RegressionLearner,
+                      SurvivalLearner)
 
 
 class RandomForestLearner(Learner):
@@ -11,7 +12,7 @@ class RandomForestClassifier(RandomForestLearner, ClassificationLearner):
     """Learner for training random forests for classification problems.
 
     Julia Equivalent:
-    `IAI.RandomForestClassifier <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.RandomForestClassifier>`
+    `IAI.RandomForestClassifier <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.RandomForestClassifier>`
 
     Examples
     --------
@@ -36,7 +37,7 @@ class RandomForestRegressor(RandomForestLearner, RegressionLearner):
     """Learner for training random forests for regression problems.
 
     Julia Equivalent:
-    `IAI.RandomForestRegressor <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.RandomForestRegressor>`
+    `IAI.RandomForestRegressor <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.RandomForestRegressor>`
 
     Examples
     --------
@@ -57,6 +58,31 @@ class RandomForestRegressor(RandomForestLearner, RegressionLearner):
         super().__init__(jl_obj)
 
 
+class RandomForestSurvivalLearner(RandomForestLearner, SurvivalLearner):
+    """Learner for training random forests for survival problems.
+
+    Julia Equivalent:
+    `IAI.RandomForestSurvivalLearner <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.RandomForestSurvivalLearner>`
+
+    Examples
+    --------
+    >>> iai.RandomForestSurvivalLearner(**kwargs)
+
+    Parameters
+    ----------
+    Use keyword arguments to set parameters on the resulting learner. Refer to
+    the Julia documentation for available parameters.
+
+    Compatibility
+    -------------
+    Requires IAI version 2.2 or higher.
+    """
+    def __init__(self, *args, **kwargs):
+        _requires_iai_version("2.2.0", "RandomForestSurvivalLearner")
+        jl_obj = _IAI.RandomForestSurvivalLearner_convert(*args, **kwargs)
+        super().__init__(jl_obj)
+
+
 class XGBoostLearner(Learner):
     """Abstract type encompassing all XGBoost learners."""
 
@@ -64,7 +90,7 @@ class XGBoostLearner(Learner):
         """Write the internal booster saved in the learner to `filename`.
 
         Julia Equivalent:
-        `IAI.write_booster <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.write_booster>`
+        `IAI.write_booster <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.write_booster>`
 
         Examples
         --------
@@ -81,7 +107,7 @@ class XGBoostLearner(Learner):
         """Calculate SHAP values for all points in the features `X` using `lnr`.
 
         Julia Equivalent:
-        `IAI.predict_shap <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.predict_shap>`
+        `IAI.predict_shap <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.predict_shap>`
 
         Examples
         --------
@@ -99,7 +125,7 @@ class XGBoostClassifier(XGBoostLearner, ClassificationLearner):
     """Learner for training XGBoost models for classification problems.
 
     Julia Equivalent:
-    `IAI.XGBoostClassifier <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.XGBoostClassifier>`
+    `IAI.XGBoostClassifier <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.XGBoostClassifier>`
 
     Examples
     --------
@@ -124,7 +150,7 @@ class XGBoostRegressor(XGBoostLearner, RegressionLearner):
     """Learner for training XGBoost models for regression problems.
 
     Julia Equivalent:
-    `IAI.XGBoostRegressor <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.XGBoostRegressor>`
+    `IAI.XGBoostRegressor <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.XGBoostRegressor>`
 
     Examples
     --------
@@ -145,6 +171,31 @@ class XGBoostRegressor(XGBoostLearner, RegressionLearner):
         super().__init__(jl_obj)
 
 
+class XGBoostSurvivalLearner(XGBoostLearner, SurvivalLearner):
+    """Learner for training XGBoost models for survival problems.
+
+    Julia Equivalent:
+    `IAI.XGBoostSurvivalLearner <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.XGBoostSurvivalLearner>`
+
+    Examples
+    --------
+    >>> iai.XGBoostSurvivalLearner(**kwargs)
+
+    Parameters
+    ----------
+    Use keyword arguments to set parameters on the resulting learner. Refer to
+    the Julia documentation for available parameters.
+
+    Compatibility
+    -------------
+    Requires IAI version 2.2 or higher.
+    """
+    def __init__(self, *args, **kwargs):
+        _requires_iai_version("2.2.0", "XGBoostSurvivalLearner")
+        jl_obj = _IAI.XGBoostSurvivalLearner_convert(*args, **kwargs)
+        super().__init__(jl_obj)
+
+
 class GLMNetLearner(Learner):
     """Abstract type encompassing all GLMNet learners."""
 
@@ -152,7 +203,7 @@ class GLMNetLearner(Learner):
         """Return the number of fits along the path in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_fits <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.get_num_fits>`
+        `IAI.get_num_fits <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.get_num_fits>`
 
         Examples
         --------
@@ -169,7 +220,7 @@ class GLMNetLearner(Learner):
         """Return the constant term in the prediction in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prediction_constant <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.get_prediction_constant>`
+        `IAI.get_prediction_constant <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.get_prediction_constant>`
 
         Examples
         --------
@@ -195,7 +246,7 @@ class GLMNetLearner(Learner):
         prediction in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prediction_weights <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.get_prediction_weights>`
+        `IAI.get_prediction_weights <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.get_prediction_weights>`
 
         Examples
         --------
@@ -221,7 +272,7 @@ class GLMNetCVRegressor(GLMNetLearner, RegressionLearner):
     """Learner for training GLMNet models for regression problems.
 
     Julia Equivalent:
-    `IAI.GLMNetCVRegressor <https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.GLMNetCVRegressor>`
+    `IAI.GLMNetCVRegressor <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.GLMNetCVRegressor>`
 
     Examples
     --------
