@@ -46,7 +46,6 @@ import julia as _julia
 _IAI = _julia.core.JuliaModuleLoader().load_module("Main.IAI")
 
 
-# Import Julia modules
 from julia import Random as _Random
 def set_julia_seed(*args):
     """Set the random seed in Julia to `seed`.
@@ -61,6 +60,30 @@ def set_julia_seed(*args):
     return _Random.seed_b(*args)
 
 
+from julia import Distributed as _Distributed
+def add_julia_processes(*args):
+    """Add additional Julia worker processes to parallelize workloads.
+
+    Julia Equivalent:
+    `Distributed.addprocs <https://docs.julialang.org/en/v1/stdlib/Distributed/#Distributed.addprocs>`
+
+    For more information, refer to the
+    `documentation on parallelization <https://docs.interpretable.ai/stable/IAIBase/advanced/#IAIBase-Parallelization-1>`
+
+    Examples
+    --------
+    >>> iai.add_julia_processes(3)
+    """
+    out = _Distributed.addprocs(*args)
+
+    # We need to load IAI on all processes
+    # NB: If using system image this is automatic
+    if not _Main.eval('isdefined(Main, :IAISysImg)'):
+        _Main.eval('import Distributed; Distributed.@everywhere import IAI')
+
+    return out
+
+
 def _get_learner_type(jl_obj):
     if _Main.isa(jl_obj, _IAI.OptimalTreeClassifier):
         L = OptimalTreeClassifier
