@@ -1,7 +1,8 @@
 from .iai import _IAI, _requires_iai_version, GridSearch
-from .iaibase import (SupervisedLearner, ClassificationLearner,
+from .iaibase import (Learner, SupervisedLearner, ClassificationLearner,
                       RegressionLearner, SurvivalLearner, PrescriptionLearner,
                       PolicyLearner, SurvivalCurve)
+import pandas as _pd
 
 
 class TreeLearner(SupervisedLearner):
@@ -11,7 +12,7 @@ class TreeLearner(SupervisedLearner):
         """Return the number of nodes in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_nodes <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_num_nodes>`
+        `IAI.get_num_nodes <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_num_nodes>`
 
         Examples
         --------
@@ -23,7 +24,7 @@ class TreeLearner(SupervisedLearner):
         """Return `True` if node `node_index` in the trained learner is a leaf.
 
         Julia Equivalent:
-        `IAI.is_leaf <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_leaf>`
+        `IAI.is_leaf <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_leaf>`
 
         Examples
         --------
@@ -35,7 +36,7 @@ class TreeLearner(SupervisedLearner):
         """Return the depth of node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_depth <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_depth>`
+        `IAI.get_depth <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_depth>`
 
         Examples
         --------
@@ -48,7 +49,7 @@ class TreeLearner(SupervisedLearner):
         in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_samples <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_num_samples>`
+        `IAI.get_num_samples <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_num_samples>`
 
         Examples
         --------
@@ -61,7 +62,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_lower_child <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_lower_child>`
+        `IAI.get_lower_child <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_lower_child>`
 
         Examples
         --------
@@ -74,7 +75,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_parent <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_parent>`
+        `IAI.get_parent <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_parent>`
 
         Examples
         --------
@@ -87,7 +88,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_upper_child <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_upper_child>`
+        `IAI.get_upper_child <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_upper_child>`
 
         Examples
         --------
@@ -100,7 +101,7 @@ class TreeLearner(SupervisedLearner):
         parallel split.
 
         Julia Equivalent:
-        `IAI.is_parallel_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_parallel_split>`
+        `IAI.is_parallel_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_parallel_split>`
 
         Examples
         --------
@@ -113,7 +114,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split.
 
         Julia Equivalent:
-        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_hyperplane_split>`
+        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_hyperplane_split>`
 
         Examples
         --------
@@ -126,7 +127,7 @@ class TreeLearner(SupervisedLearner):
         categoric split.
 
         Julia Equivalent:
-        `IAI.is_categoric_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_categoric_split>`
+        `IAI.is_categoric_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_categoric_split>`
 
         Examples
         --------
@@ -139,7 +140,7 @@ class TreeLearner(SupervisedLearner):
         ordinal split.
 
         Julia Equivalent:
-        `IAI.is_ordinal_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_ordinal_split>`
+        `IAI.is_ordinal_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_ordinal_split>`
 
         Examples
         --------
@@ -152,7 +153,7 @@ class TreeLearner(SupervisedLearner):
         categoric/parallel split.
 
         Julia Equivalent:
-        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
+        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
 
         Examples
         --------
@@ -165,7 +166,7 @@ class TreeLearner(SupervisedLearner):
         categoric/ordinal split.
 
         Julia Equivalent:
-        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
+        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
 
         Examples
         --------
@@ -178,7 +179,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.missing_goes_lower <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.missing_goes_lower>`
+        `IAI.missing_goes_lower <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.missing_goes_lower>`
 
         Examples
         --------
@@ -191,7 +192,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_feature <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_split_feature>`
+        `IAI.get_split_feature <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_split_feature>`
 
         Examples
         --------
@@ -204,7 +205,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_threshold <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_split_threshold>`
+        `IAI.get_split_threshold <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_split_threshold>`
 
         Examples
         --------
@@ -217,7 +218,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_categories <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_split_categories>`
+        `IAI.get_split_categories <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_split_categories>`
 
         Examples
         --------
@@ -230,7 +231,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split at  node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_weights <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_split_weights>`
+        `IAI.get_split_weights <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_split_weights>`
 
         Examples
         --------
@@ -243,7 +244,7 @@ class TreeLearner(SupervisedLearner):
         features `X` falls.
 
         Julia Equivalent:
-        `IAI.apply <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.apply>`
+        `IAI.apply <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.apply>`
 
         Examples
         --------
@@ -256,7 +257,7 @@ class TreeLearner(SupervisedLearner):
         each node in the learner.
 
         Julia Equivalent:
-        `IAI.apply_nodes <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.apply_nodes>`
+        `IAI.apply_nodes <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.apply_nodes>`
 
         Examples
         --------
@@ -270,7 +271,7 @@ class TreeLearner(SupervisedLearner):
         the features `X` passes through the `j`th node in the learner.
 
         Julia Equivalent:
-        `IAI.decision_path <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.decision_path>`
+        `IAI.decision_path <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.decision_path>`
 
         Examples
         --------
@@ -283,7 +284,7 @@ class TreeLearner(SupervisedLearner):
         features `X`.
 
         Julia Equivalent:
-        `IAI.print_path <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.print_path>`
+        `IAI.print_path <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.print_path>`
 
         Examples
         --------
@@ -299,7 +300,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_png <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_png>`
+        `IAI.write_png <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_png>`
 
         Examples
         --------
@@ -315,7 +316,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_pdf <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_pdf>`
+        `IAI.write_pdf <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_pdf>`
 
         Compatibility
         -------------
@@ -336,7 +337,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_svg <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_svg>`
+        `IAI.write_svg <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_svg>`
 
         Compatibility
         -------------
@@ -354,7 +355,7 @@ class TreeLearner(SupervisedLearner):
         [.dot format](http://www.graphviz.org/content/dot-language/).
 
         Julia Equivalent:
-        `IAI.write_dot <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_dot>`
+        `IAI.write_dot <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_dot>`
 
         Examples
         --------
@@ -367,7 +368,7 @@ class TreeLearner(SupervisedLearner):
         HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -379,7 +380,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive visualization of learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -392,7 +393,7 @@ class TreeLearner(SupervisedLearner):
         HTML.
 
         Julia Equivalent:
-        `IAI.write_questionnaire <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_questionnaire>`
+        `IAI.write_questionnaire <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_questionnaire>`
 
         Examples
         --------
@@ -405,7 +406,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive questionnaire based on learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_questionnaire <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.show_questionnaire>`
+        `IAI.show_questionnaire <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.show_questionnaire>`
 
         Examples
         --------
@@ -413,6 +414,57 @@ class TreeLearner(SupervisedLearner):
         """
         return _IAI.show_questionnaire_convert(self._jl_obj, **kwargs)
 
+    def variable_importance_similarity(self, new_lnr, *args, **kwargs):
+        """Calculate similarity between this learner and another tree learner
+        using variable importance scores.
+
+        Julia Equivalent:
+        `IAI.variable_importance_similarity <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.variable_importance_similarity>`
+
+        Examples
+        --------
+        Calculate similarity scores between the final tree in this learner and
+        all trees in `new_lnr`
+
+        >>> lnr.variable_importance_similarity(new_lnr)
+
+        Calculate similarity scores between the final tree in this learner and
+        all trees in `new_lnr` using the data `X` and `y` with `criterion`
+
+        >>> lnr.variable_importance_similarity(new_lnr, X, y,
+                                               criterion='default')
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "variable_importance_similarity")
+        if not isinstance(new_lnr, Learner):
+            raise TypeError("new_lnr is not a Learner")
+        return _IAI.variable_importance_similarity_convert(
+            self._jl_obj, new_lnr._jl_obj, *args, **kwargs)
+
+    def get_tree(self, index):
+        """Return a copy of the learner that uses the tree at `index` rather
+        than the tree with the best training objective.
+
+        Julia Equivalent:
+        `IAI.get_tree <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_tree>`
+
+        Examples
+        --------
+        >>> lnr.get_tree(index)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "get_tree")
+        jl_obj = _IAI.get_tree(self._jl_obj, index)
+        new_lnr = type(self)()
+        Learner.__init__(new_lnr, jl_obj)
+        return new_lnr
+
 
 class ClassificationTreeLearner(ClassificationLearner):
     """Abstract type encompassing all tree-based learners with classification
@@ -424,7 +476,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         learner.
 
         Julia Equivalent:
-        `IAI.get_classification_label <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_classification_label>`
+        `IAI.get_classification_label <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_classification_label>`
 
         Examples
         --------
@@ -438,7 +490,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_classification_proba <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_classification_proba>`
+        `IAI.get_classification_proba <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_classification_proba>`
 
         Examples
         --------
@@ -454,7 +506,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         will be simplified after all changes have been made.
 
         Julia Equivalent:
-        `IAI.set_threshold! <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.set_threshold!>`
+        `IAI.set_threshold! <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.set_threshold!>`
 
         Examples
         --------
@@ -467,7 +519,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         """Show the probability of `display_label` when visualizing learner.
 
         Julia Equivalent:
-        `IAI.set_display_label! <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.set_display_label!>`
+        `IAI.set_display_label! <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.set_display_label!>`
 
         Examples
         --------
@@ -481,7 +533,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         predicted label when visualizing learner.
 
         Julia Equivalent:
-        `IAI.reset_display_label! <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.reset_display_label!>`
+        `IAI.reset_display_label! <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.reset_display_label!>`
 
         Examples
         --------
@@ -501,7 +553,7 @@ class RegressionTreeLearner(RegressionLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
 
         Examples
         --------
@@ -515,7 +567,7 @@ class RegressionTreeLearner(RegressionLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
 
         Examples
         --------
@@ -531,11 +583,11 @@ class SurvivalTreeLearner(SurvivalLearner):
 
     def get_survival_curve(self, node_index, **kwargs):
         """Return the
-        `SurvivalCurve <https://docs.interpretable.ai/v2.1.0/IAI-Python/reference/#SurvivalCurve>`
+        `SurvivalCurve <https://docs.interpretable.ai/v2.2.0/IAI-Python/reference/#SurvivalCurve>`
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_curve <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_survival_curve>`
+        `IAI.get_survival_curve <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_survival_curve>`
 
         Examples
         --------
@@ -550,7 +602,7 @@ class SurvivalTreeLearner(SurvivalLearner):
         the trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_expected_time <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_survival_expected_time>`
+        `IAI.get_survival_expected_time <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_survival_expected_time>`
 
         Examples
         --------
@@ -569,7 +621,7 @@ class SurvivalTreeLearner(SurvivalLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_hazard <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_survival_hazard>`
+        `IAI.get_survival_hazard <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_survival_hazard>`
 
         Examples
         --------
@@ -594,7 +646,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
+        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
 
         Examples
         --------
@@ -609,7 +661,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
 
         Examples
         --------
@@ -623,7 +675,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         `treatment` at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
 
         Examples
         --------
@@ -642,7 +694,7 @@ class PolicyTreeLearner(PolicyLearner):
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_policy_treatment_rank <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_policy_treatment_rank>`
+        `IAI.get_policy_treatment_rank <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_policy_treatment_rank>`
 
         Examples
         --------
@@ -661,7 +713,7 @@ class PolicyTreeLearner(PolicyLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_policy_treatment_outcome <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_policy_treatment_outcome>`
+        `IAI.get_policy_treatment_outcome <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_policy_treatment_outcome>`
 
         Examples
         --------
@@ -691,7 +743,7 @@ class AbstractVisualization():
         """Write interactive browser visualization to `filename` as HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -703,7 +755,7 @@ class AbstractVisualization():
         """Show interactive visualization in default browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -716,7 +768,7 @@ class TreePlot(AbstractVisualization):
     """Specify an interactive tree visualization of `lnr`.
 
     Julia Equivalent:
-    `IAI.TreePlot <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.TreePlot>`
+    `IAI.TreePlot <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.TreePlot>`
 
     Examples
     --------
@@ -725,7 +777,7 @@ class TreePlot(AbstractVisualization):
     Parameters
     ----------
     Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.2.0/IAITrees/advanced/#Advanced-Visualization-1>`
     for available parameters.
 
     Compatibility
@@ -742,7 +794,7 @@ class Questionnaire(AbstractVisualization):
     """Specify an interactive questionnaire of `lnr`.
 
     Julia Equivalent:
-    `IAI.Questionnaire <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.Questionnaire>`
+    `IAI.Questionnaire <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.Questionnaire>`
 
     Examples
     --------
@@ -752,7 +804,7 @@ class Questionnaire(AbstractVisualization):
     ----------
 
     Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.2.0/IAITrees/advanced/#Advanced-Visualization-1>`
     for available parameters.
 
     Compatibility
@@ -769,13 +821,13 @@ class MultiQuestionnaire(AbstractVisualization):
     """Specify an interactive questionnaire of multiple tree learners
 
     Julia Equivalent:
-    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
+    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
 
     Examples
     --------
     Constructs an interactive questionnaire using multiple tree learners from
     specified questions. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.2.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
     >>> iai.MultiQuestionnaire(questions)
@@ -806,13 +858,13 @@ class MultiTreePlot(AbstractVisualization):
     """Specify an interactive tree visualization of multiple tree learners
 
     Julia Equivalent:
-    `IAI.MultiTreePlot <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.MultiTreePlot>`
+    `IAI.MultiTreePlot <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.MultiTreePlot>`
 
     Examples
     --------
     Constructs an interactive tree visualization using multiple tree learners
     from specified questions. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.2.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
     >>> iai.MultiTreePlot(questions)
@@ -837,3 +889,249 @@ class MultiTreePlot(AbstractVisualization):
             _requires_iai_version("1.1.0", "MultiTreePlot")
             jl_obj = _IAI.MultiTreePlot_convert(*args)
         super().__init__(jl_obj)
+
+
+class SimilarityComparison(AbstractVisualization):
+    """Conduct a similarity comparison between the final tree in `orig_lnr` and
+    all trees in `new_lnr` to consider the tradeoff between training
+    performance and similarity to the original tree as measured by
+    `deviations`.
+
+    Refer to the
+    `documentation on tree stability <https://docs.interpretable.ai/v2.2.0/IAITrees/stability/#Tree-Stability-1>`
+    for more information.
+
+    Julia Equivalent:
+    `IAI.SimilarityComparison <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.SimilarityComparison>`
+
+    Examples
+    --------
+    >>> iai.SimilarityComparison(orig_lnr, new_lnr, deviations)
+
+    Compatibility
+    -------------
+    Requires IAI version 2.2 or higher.
+    """
+    def __init__(self, orig_lnr, new_lnr, *args, **kwargs):
+        _requires_iai_version("2.2.0", "SimilarityComparison")
+        if not isinstance(orig_lnr, TreeLearner):
+            raise TypeError("orig_lnr is not a TreeLearner")
+        if not isinstance(new_lnr, TreeLearner):
+            raise TypeError("new_lnr is not a TreeLearner")
+        jl_obj = _IAI.SimilarityComparison_convert(
+            orig_lnr._jl_obj, new_lnr._jl_obj, *args, **kwargs)
+        super().__init__(jl_obj)
+
+    def get_train_errors(self, *args, **kwargs):
+        """Extract the training objective value for each candidate tree in the
+        comparison, where a lower value indicates a better solution.
+
+        Julia Equivalent:
+        `IAI.get_train_errors <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_train_errors>`
+
+        Examples
+        --------
+        >>> lnr.get_train_errors()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "get_train_errors")
+        return _IAI.get_train_errors_convert(self._jl_obj, *args, **kwargs)
+
+    def plot(self):
+        """Plot the similarity comparison results.
+
+        Returns a
+        `matplotlib.figure.Figure <https://matplotlib.org/stable/api/figure_api.html?highlight=figure#matplotlib.figure.Figure>`
+        containing the plotted results.
+
+        In a Jupyter Notebook, the plot will be shown automatically. In a
+        terminal, you can show the plot with `similarity.plot().show()`.
+
+        Examples
+        --------
+        >>> similarity.plot()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "plot")
+
+        from julia import Main
+        deviations = Main.eval("s -> s.deviations")(self._jl_obj)
+        train_errors = self.get_train_errors()
+        best_i = Main.eval("s -> s.best_tree_index")(self._jl_obj) - 1
+
+        plot_data = _pd.DataFrame({'deviations': deviations,
+                                   'train_errors': train_errors})
+        # Add all trees
+        ax = plot_data.plot(x='deviations', y='train_errors',
+                            label='All trees', kind='scatter', c='C0')
+        # Add best tree
+        ax = plot_data.iloc[best_i:best_i + 1, :].plot(
+            ax=ax, x='deviations', y='train_errors', label='Selected tree',
+            kind='scatter', c='C1')
+
+        ax.set_xlabel('Deviation from original tree (lower is better)')
+        ax.set_ylabel('Training objective value (lower is better)')
+        return ax.get_figure()
+
+
+class StabilityAnalysis(AbstractVisualization):
+    """Conduct a stability analysis of the trees in a tree learner.
+
+    Refer to the
+    `documentation on tree stability <https://docs.interpretable.ai/v2.2.0/IAITrees/stability/#Tree-Stability-1>`
+    for more information.
+
+    Julia Equivalent:
+    `IAI.StabilityAnalysis <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.StabilityAnalysis>`
+
+    Examples
+    --------
+
+    Conduct a stability analysis of the trees in `lnr`, using similarity scores
+    calculated during training
+
+    >>> iai.StabilityAnalysis(lnr)
+
+    Conduct a stability analysis of the trees in `lnr`, using similarity scores
+    calculated with the data `X`, `y` and `criterion`
+
+    >>> iai.StabilityAnalysis(lnr, X, y, criterion='default')
+
+    Compatibility
+    -------------
+    Requires IAI version 2.2 or higher.
+    """
+    def __init__(self, lnr, *args, **kwargs):
+        _requires_iai_version("2.2.0", "StabilityAnalysis")
+        if not isinstance(lnr, TreeLearner):
+            raise TypeError("lnr is not a TreeLearner")
+        jl_obj = _IAI.StabilityAnalysis_convert(lnr._jl_obj, *args, **kwargs)
+        super().__init__(jl_obj)
+
+    def get_stability_results(self, *args, **kwargs):
+        """Return the trained trees in order of increasing objective value,
+        along with their variable importance scores for each feature.
+
+        Julia Equivalent:
+        `IAI.get_stability_results <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_stability_results>`
+
+        Examples
+        --------
+        >>> stability.get_stability_results()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "get_stability_results")
+        return _IAI.get_stability_results_convert(self._jl_obj, *args, **kwargs)
+
+    def get_cluster_assignments(self, *args, **kwargs):
+        """Return the indices of the trees assigned to each cluster, under the
+        clustering of the best `num_trees` trees.
+
+        Julia Equivalent:
+        `IAI.get_cluster_assignments <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_cluster_assignments>`
+
+        Examples
+        --------
+        >>> stability.get_cluster_assignments(num_trees)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "get_cluster_assignments")
+        return _IAI.get_cluster_assignments_convert(self._jl_obj, *args,
+                                                    **kwargs)
+
+    def get_cluster_details(self, *args, **kwargs):
+        """Return the centroid information for each cluster, under the
+        clustering of the best `num_trees` trees.
+
+        Julia Equivalent:
+        `IAI.get_cluster_details <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_cluster_details>`
+
+        Examples
+        --------
+        >>> stability.get_cluster_details(num_trees)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "get_cluster_details")
+        return _IAI.get_cluster_details_convert(self._jl_obj, *args,
+                                                **kwargs)
+
+    def get_cluster_distances(self, *args, **kwargs):
+        """Return the distances between the centroids of each pair of clusters,
+        under the clustering of the best `num_trees` trees.
+
+        Julia Equivalent:
+        `IAI.get_cluster_distances <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_cluster_distances>`
+
+        Examples
+        --------
+        >>> stability.get_cluster_distances(num_trees)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "get_cluster_distances")
+        return _IAI.get_cluster_distances_convert(self._jl_obj, *args,
+                                                  **kwargs)
+
+    def plot(self):
+        """Plot the stability analysis results.
+
+        Returns a
+        `matplotlib.figure.Figure <https://matplotlib.org/stable/api/figure_api.html?highlight=figure#matplotlib.figure.Figure>`
+        containing the plotted results.
+
+        In a Jupyter Notebook, the plot will be shown automatically. In a
+        terminal, you can show the plot with `stability.plot().show()`.
+
+        Examples
+        --------
+        >>> stability.plot()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "plot")
+
+        from julia import Main
+        train_errors = Main.eval("s -> s.train_errors")(self._jl_obj)
+        n_clusts = Main.eval("s -> size.(s.cluster_centers, 2)")(self._jl_obj)
+        cluster_r2 = Main.eval("s -> s.cluster_r2")(self._jl_obj)
+
+        plot_data = _pd.DataFrame({'train_errors': train_errors,
+                                   'n_clusts': n_clusts,
+                                   'cluster_r2': cluster_r2})
+
+        import matplotlib.pyplot as plt
+        fig, axs = plt.subplots(3, sharex=True, figsize=(6, 6))
+
+        # Plot 1
+        ax = plot_data.plot(ax=axs[0], y='train_errors', legend=False)
+        ax.set_ylabel('Training objective')
+
+        # Plot 2
+        ax = plot_data.plot(ax=axs[1], y='n_clusts', legend=False)
+        ax.set_ylabel('Number of clusters')
+
+        # Plot 3
+        ax = plot_data.plot(ax=axs[2], y='cluster_r2', legend=False)
+        ax.set_xlabel('Trees (ordered by training objective)')
+        ax.set_ylabel('Number of clusters')
+
+        return fig
